@@ -2,14 +2,13 @@ print.profile.gnm <- function (x, digits = max(3, getOption("digits") - 3), ...)
 {
     #if (attr(x, "eliminate"))
        # coefs <- coefs[-seq(attr(x$cov.scaled, "eliminate")), ]
-    
+
     if (length(x)) {
         if (any(sapply(x, is.null)))
             cat("\nProfile is NULL where coefficient has been constrained or",
                 "is unidentified\n\n")
-        print.default(x)
+        print.default(x[[1]])
     }
-    else cat("\nNo ", "non-eliminated "[attr(x$cov.scaled, "eliminate") > 0],
-             "coefficients\n\n", sep = "")
+    else cat("\nNo coefficients profiled.\n\n", sep = "")
     invisible(x)
 }
